Stan Math Library: stan/math/prim/mat/fun/minus.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

minus.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_MINUS_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_MINUS_HPP
3
4 namespace stan {
5 namespace math {
6
14 template <typename T>
15 inline
16 T minus(const T& x) {
17 return -x;
18 }
19
20 }
21 }
22 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::minus
T minus(const T &x)
Returns the negation of the specified scalar or matrix.
Definition: minus.hpp:16

[ Stan Home Page ] © 2011–2016, Stan Development Team.